**Directory Structure:**

- `InfGrPaper/`
	- `auxLoaddata/`
		- holds model specific code to update the size of the data matrix for auxiliary constructed "observables" such as fundamental inflation (fills with NaNs so as not to affect the filtering and smoothing procedures) 
	- `auxMeasur/`
		- updates the measurement equations for auxiliary variables 
	- `auxSpecs/`
		- updates auxiliary variable specifications such as how the variables need to be transformed, their names, etc. 
	- `auxUpdateYY/`
		- uses smoothed ex-post states to generate the black and dashed black lines seen in the forecast figures 
	- `data/`
		- contains a .mat file with realtime vintages of data for the model 
	- `gensys/`
		- contain C. Sims procedures for solving linear rational expectations equations 
	- `gensys2/`
		- these are the procedures which implement section I.D.2. Ex-Post Accounting for the ZLB and Forward Guidance 
	- `graphs/`
	    - figure_#/
	    - ...
	- `hairplot_functions/`
		- procedures to generate marginal cost hairs 
	- `helper_functions/`
	- `initialization/`
	- `kalfilter/`
	- `main_functions/`
		- main code that generates forecasts, smoothed states, plots of such objects, etc. 
	- `models/`
		- this code specificies the eq. conditions, measurement equation, states, equations, etc. for each model 
	- `para_compare_table/`
	- `phillips/`
		- estimates and forecasts using reduced form phillips curve 
	- `priors/`
		- prior specifications for each model 
	- `save/`
	    - `hairs/`
	    - `mc_cond/`
	    - `phillips/`
	    - `two_model_fcast_decomp/`
	Documentation
	figures_script.m
	setpath.m

**Quick run guide:**

*Running Figures Only*

Running <figures_script.m> from the matlab console should generate
figures 1-4,6-8,A1-A6 from the paper (figure 5 was not generated in
matlab). Figures are saved in corresponding folders in the grahps/
directory.  For example, figures 1,2 and 3 are saved in
graphs/figure_1_2_3/.

In some cases, the figures will be saved into a dated subfolder of
their figure_#/ directory. In graphs/figure_1_2_3/, the earlier dated
subfolder contains figure 1, the left panel of figure 2 and
figure 3. The later dated subfolder has the right panel of figure 2.

*Note*: There are some flags in the code and warnings that will show
 up in your matlab console when running this that you should not worry
 about, as this replication code was at one point part of a larger
 code framework.

*Replicating the mode*
To replicate the working mode (`./save/mhparam9049354700020085020Mode`), run `estimate.m` as follows:
	
	```matlab
	> setpath;
	> estimate;
	```

`estimate` will return after finding the parameter mode and writing it
to the file `spath/mhparam9049Mode`, where `spath` by default is To
find the Hessian matrix and run the Metropolis-Hastings MCMC method,
comment out line 232 in the misleadingly-named file
`estimation/gibb.m`.

*A note about the model parameters:*


The estimated model parameters using data up until the great recession
can be found for SW2007 and SWpiFF (model 904) in the save/ directory.
These are the posterior modal estimates. The parameter estimates from
the SW 2007 paper are in the binary file named
`smetsAndWouters2007ParaMode` and the SWpiFF parameter mode is called
`mhparam9049354700020085020Mode`.  To look at examine these parameters
one can run the following.

	```matlab
	> f = fopen(parameter_file_name,'r');
	> para = fread(f,'single');
	```
	
To transform the parameters appropriately and assign them one can use
the functions getpara00_904 for SWpiFF and getpara00_803 for SW (these
can be found in models/). These functions take para as an input. See
the .m files to see how to assign the output to the correct DSGE
parameters.


**DISCLAIMER** 
Copyright (c) 2015, Federal Reserve Bank of New York
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


